/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default [
  {
    path: "",
    name: "Infrastructure",
    meta: {
      title: "infrastructure",
      icon: "scatter_plot",
      hasGroup: true,
    },
    redirect: "/linux",
    children: [
      {
        path: "/linux",
        name: "Linux",
        meta: {
          title: "linux",
          layer: "OS_LINUX",
        },
      },
      {
        path: "/linux/tab/:activeTabIndex",
        name: "LinuxActiveTabIndex",
        meta: {
          title: "linux",
          notShow: true,
          layer: "OS_LINUX",
        },
      },
      {
        path: "/windows",
        name: "Windows",
        meta: {
          title: "windows",
          layer: "OS_WINDOWS",
        },
      },
      {
        path: "/windows/tab/:activeTabIndex",
        name: "WindowsActiveTabIndex",
        meta: {
          title: "windows",
          notShow: true,
          layer: "OS_WINDOWS",
        },
      },
    ],
  },
];
